==> kde-runtime-4.8.5-arm-1.tgz: install/doinst.sh <==

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
fi

( cd usr/bin ; rm -rf kdesu )
( cd usr/bin ; ln -sf /usr/lib/kde4/libexec/kdesu kdesu )
( cd usr/lib ; rm -rf libnepomukdatamanagement.so )
( cd usr/lib ; ln -sf libnepomukdatamanagement.so.4 libnepomukdatamanagement.so )
( cd usr/lib ; rm -rf libnepomuksync.so.4 )
( cd usr/lib ; ln -sf libnepomuksync.so.4.8.0 libnepomuksync.so.4 )
( cd usr/lib ; rm -rf libmolletnetwork.so )
( cd usr/lib ; ln -sf libmolletnetwork.so.4 libmolletnetwork.so )
( cd usr/lib ; rm -rf libnepomukdatamanagement.so.4 )
( cd usr/lib ; ln -sf libnepomukdatamanagement.so.4.8.0 libnepomukdatamanagement.so.4 )
( cd usr/lib ; rm -rf libnepomuksync.so )
( cd usr/lib ; ln -sf libnepomuksync.so.4 libnepomuksync.so )
( cd usr/lib ; rm -rf libkwalletbackend.so.4 )
( cd usr/lib ; ln -sf libkwalletbackend.so.4.8.0 libkwalletbackend.so.4 )
( cd usr/lib ; rm -rf libmolletnetwork.so.4 )
( cd usr/lib ; ln -sf libmolletnetwork.so.4.8.0 libmolletnetwork.so.4 )
( cd usr/lib ; rm -rf libkwalletbackend.so )
( cd usr/lib ; ln -sf libkwalletbackend.so.4 libkwalletbackend.so )
( cd usr/doc/HTML/en/kdesu ; rm -rf common )
( cd usr/doc/HTML/en/kdesu ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/network ; rm -rf common )
( cd usr/doc/HTML/en/network ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/nepomuksearch ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/nepomuksearch ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/cgi ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/cgi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/smb ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/smb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/bookmarks ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/bookmarks ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/tar ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/tar ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/finger ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/finger ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/floppy ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/floppy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/xz ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/xz ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/sftp ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/sftp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/gzip ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/gzip ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/thumbnail ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/bzip2 ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/bzip2 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/nfs ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/nfs ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/info ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/info ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/fish ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/fish ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/man ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/man ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/onlinehelp ; rm -rf common )
( cd usr/doc/HTML/en/onlinehelp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/cookies ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kded ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kded ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/spellchecking ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/phonon ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/phonon ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/icons ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/icons ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-java-js ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-java-js ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/proxy ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/smb ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/smb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/bookmarks ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/bookmarks ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/trash ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/trash ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/netpref ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/attica ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/attica ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/language ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/language ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmcss ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmcgi ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmcgi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-adblock ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-adblock ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/history ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/history ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-plugins ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-plugins ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/componentchooser ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/componentchooser ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcm_ssl ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcm_ssl ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmnotify ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/solid-device-automounter ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/solid-device-automounter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/useragent ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/ebrowsing ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/cache ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/cache ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/filemanager ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-behavior ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-behavior ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/emoticons ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/emoticons ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/nepomuk ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/nepomuk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/filetypes ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/performance ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/performance ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-general ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-general ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmlaunch ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/khelpcenter/documentationnotfound ; rm -rf common )
( cd usr/doc/HTML/en/khelpcenter/documentationnotfound ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/khelpcenter ; rm -rf common )
( cd usr/doc/HTML/en/khelpcenter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/khelpcenter/glossary ; rm -rf common )
( cd usr/doc/HTML/en/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kdebugdialog ; rm -rf common )
( cd usr/doc/HTML/en/kdebugdialog ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/knetattach ; rm -rf common )
( cd usr/doc/HTML/en/knetattach ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/icons ; rm -rf default.kde4 )
( cd usr/share/icons ; ln -sf oxygen default.kde4 )

==> kde-runtime-4.10.5-arm-1.tgz: install/doinst.sh <==

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
fi

( cd usr/bin ; rm -rf kdesu )
( cd usr/bin ; ln -sf /usr/lib/kde4/libexec/kdesu kdesu )
( cd usr/lib ; rm -rf libmolletnetwork.so.4 )
( cd usr/lib ; ln -sf libmolletnetwork.so.4.10.5 libmolletnetwork.so.4 )
( cd usr/lib ; rm -rf libkwalletbackend.so )
( cd usr/lib ; ln -sf libkwalletbackend.so.4 libkwalletbackend.so )
( cd usr/lib ; rm -rf libkwalletbackend.so.4 )
( cd usr/lib ; ln -sf libkwalletbackend.so.4.10.5 libkwalletbackend.so.4 )
( cd usr/lib ; rm -rf libmolletnetwork.so )
( cd usr/lib ; ln -sf libmolletnetwork.so.4 libmolletnetwork.so )
( cd usr/share/icons ; rm -rf default.kde4 )
( cd usr/share/icons ; ln -sf oxygen default.kde4 )
( cd usr/doc/HTML/en/kioslave/smb ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/smb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/cgi ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/cgi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/bzip2 ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/bzip2 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/gzip ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/gzip ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/nfs ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/nfs ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/fish ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/fish ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/nepomuksearch ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/nepomuksearch ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/thumbnail ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/thumbnail ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/bookmarks ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/bookmarks ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/tar ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/tar ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/man ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/man ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/sftp ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/sftp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/info ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/info ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/xz ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/xz ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/finger ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/finger ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/floppy ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/floppy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kdesu ; rm -rf common )
( cd usr/doc/HTML/en/kdesu ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/knetattach ; rm -rf common )
( cd usr/doc/HTML/en/knetattach ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/network ; rm -rf common )
( cd usr/doc/HTML/en/network ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/fundamentals ; rm -rf common )
( cd usr/doc/HTML/en/fundamentals ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/onlinehelp ; rm -rf common )
( cd usr/doc/HTML/en/onlinehelp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmlaunch ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/smb ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/smb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/emoticons ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/emoticons ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmcss ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-adblock ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-adblock ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmcgi ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmcgi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/filetypes ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/ebrowsing ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/cookies ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/netpref ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-behavior ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-behavior ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/nepomuk ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/nepomuk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/useragent ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/history ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/history ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/proxy ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/phonon ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/phonon ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/solid-device-automounter ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/solid-device-automounter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/cache ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/cache ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/spellchecking ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kded ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kded ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcm_ssl ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcm_ssl ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/trash ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/trash ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/attica ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/attica ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/performance ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/performance ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-general ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-general ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/bookmarks ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/bookmarks ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/language ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/language ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/filemanager ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/componentchooser ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/componentchooser ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/icons ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/icons ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-java-js ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-java-js ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/khtml-plugins ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/khtml-plugins ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kcontrol/kcmnotify ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kdebugdialog ; rm -rf common )
( cd usr/doc/HTML/en/kdebugdialog ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/khelpcenter/documentationnotfound ; rm -rf common )
( cd usr/doc/HTML/en/khelpcenter/documentationnotfound ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/khelpcenter ; rm -rf common )
( cd usr/doc/HTML/en/khelpcenter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/khelpcenter/glossary ; rm -rf common )
( cd usr/doc/HTML/en/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/en/common common )
